// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

namespace Apache.Iggy.Enums;

/// <summary>
///     Enum representing the various compression methods available for snapshots
/// </summary>
public enum SnapshotCompression
{
    /// Store the file as is
    Stored = 1,

    /// Compress the file using Deflate
    Deflated = 2,

    /// Compress the file using BZIP2
    Bzip2 = 3,

    /// Compress the file using ZStandard
    Zstd = 4,

    /// Compress the file using LZMA
    Lzma = 5,

    /// Compress the file using XZ
    Xz = 6
}
